@@ -38,7 +38,7 @@ class Subscriber(object):
 
     def amqp_callback(self, channel, method, header, body):
         try:
-            logger.debug('Subscription callback. Method = "%s", body = "".' % (method.routing_key, body))
+            logger.debug('Subscription callback. Method = "%s", body = "%s".' % (method.routing_key, body))
 
             self.callback(json.loads(body), Publisher(channel, self.exchange))
             channel.basic_ack(delivery_tag=method.delivery_tag)
